==> anari-sdk-0.11.1-1-riscv64.pkg.tar.zst: usr/lib/cmake/anari-0.11.1/anari_Exports-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "anari::anari" for configuration "Release"
set_property(TARGET anari::anari APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(anari::anari PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libanari.so.0.11.1"
  IMPORTED_SONAME_RELEASE "libanari.so.0"
  )

list(APPEND _cmake_import_check_targets anari::anari )
list(APPEND _cmake_import_check_files_for_anari::anari "${_IMPORT_PREFIX}/lib/libanari.so.0.11.1" )

# Import target "anari::anari_static" for configuration "Release"
set_property(TARGET anari::anari_static APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(anari::anari_static PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "C;CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libanari_static.a"
  )

list(APPEND _cmake_import_check_targets anari::anari_static )
list(APPEND _cmake_import_check_files_for_anari::anari_static "${_IMPORT_PREFIX}/lib/libanari_static.a" )

# Import target "anari::helium" for configuration "Release"
set_property(TARGET anari::helium APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(anari::helium PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libhelium.a"
  )

list(APPEND _cmake_import_check_targets anari::helium )
list(APPEND _cmake_import_check_files_for_anari::helium "${_IMPORT_PREFIX}/lib/libhelium.a" )

# Import target "anari::anari_library_debug" for configuration "Release"
set_property(TARGET anari::anari_library_debug APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(anari::anari_library_debug PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libanari_library_debug.so"
  IMPORTED_SONAME_RELEASE "libanari_library_debug.so"
  )

list(APPEND _cmake_import_check_targets anari::anari_library_debug )
list(APPEND _cmake_import_check_files_for_anari::anari_library_debug "${_IMPORT_PREFIX}/lib/libanari_library_debug.so" )

# Import target "anari::anari_library_sink" for configuration "Release"
set_property(TARGET anari::anari_library_sink APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(anari::anari_library_sink PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libanari_library_sink.so"
  IMPORTED_SONAME_RELEASE "libanari_library_sink.so"
  )

list(APPEND _cmake_import_check_targets anari::anari_library_sink )
list(APPEND _cmake_import_check_files_for_anari::anari_library_sink "${_IMPORT_PREFIX}/lib/libanari_library_sink.so" )

# Import target "anari::anari_test_scenes" for configuration "Release"
set_property(TARGET anari::anari_test_scenes APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(anari::anari_test_scenes PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libanari_test_scenes.so"
  IMPORTED_SONAME_RELEASE "libanari_test_scenes.so"
  )

list(APPEND _cmake_import_check_targets anari::anari_test_scenes )
list(APPEND _cmake_import_check_files_for_anari::anari_test_scenes "${_IMPORT_PREFIX}/lib/libanari_test_scenes.so" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> anari-sdk-0.13.1-1-riscv64.pkg.tar.zst: usr/lib/cmake/anari-0.13.1/anari_Exports-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "anari::anari" for configuration "Release"
set_property(TARGET anari::anari APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(anari::anari PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libanari.so.0.13.1"
  IMPORTED_SONAME_RELEASE "libanari.so.0"
  )

list(APPEND _cmake_import_check_targets anari::anari )
list(APPEND _cmake_import_check_files_for_anari::anari "${_IMPORT_PREFIX}/lib/libanari.so.0.13.1" )

# Import target "anari::anari_static" for configuration "Release"
set_property(TARGET anari::anari_static APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(anari::anari_static PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "C;CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libanari_static.a"
  )

list(APPEND _cmake_import_check_targets anari::anari_static )
list(APPEND _cmake_import_check_files_for_anari::anari_static "${_IMPORT_PREFIX}/lib/libanari_static.a" )

# Import target "anari::anari_backend" for configuration "Release"
set_property(TARGET anari::anari_backend APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(anari::anari_backend PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libanari_backend.a"
  )

list(APPEND _cmake_import_check_targets anari::anari_backend )
list(APPEND _cmake_import_check_files_for_anari::anari_backend "${_IMPORT_PREFIX}/lib/libanari_backend.a" )

# Import target "anari::anari_test_scenes" for configuration "Release"
set_property(TARGET anari::anari_test_scenes APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(anari::anari_test_scenes PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libanari_test_scenes.so"
  IMPORTED_SONAME_RELEASE "libanari_test_scenes.so"
  )

list(APPEND _cmake_import_check_targets anari::anari_test_scenes )
list(APPEND _cmake_import_check_files_for_anari::anari_test_scenes "${_IMPORT_PREFIX}/lib/libanari_test_scenes.so" )

# Import target "anari::helium" for configuration "Release"
set_property(TARGET anari::helium APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(anari::helium PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libhelium.a"
  )

list(APPEND _cmake_import_check_targets anari::helium )
list(APPEND _cmake_import_check_files_for_anari::helium "${_IMPORT_PREFIX}/lib/libhelium.a" )

# Import target "anari::anari_library_debug" for configuration "Release"
set_property(TARGET anari::anari_library_debug APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(anari::anari_library_debug PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libanari_library_debug.so"
  IMPORTED_SONAME_RELEASE "libanari_library_debug.so"
  )

list(APPEND _cmake_import_check_targets anari::anari_library_debug )
list(APPEND _cmake_import_check_files_for_anari::anari_library_debug "${_IMPORT_PREFIX}/lib/libanari_library_debug.so" )

# Import target "anari::anari_library_sink" for configuration "Release"
set_property(TARGET anari::anari_library_sink APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(anari::anari_library_sink PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libanari_library_sink.so"
  IMPORTED_SONAME_RELEASE "libanari_library_sink.so"
  )

list(APPEND _cmake_import_check_targets anari::anari_library_sink )
list(APPEND _cmake_import_check_files_for_anari::anari_library_sink "${_IMPORT_PREFIX}/lib/libanari_library_sink.so" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
